<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Peidetud kiirklahvid</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Kui sa rakenduse eelistuste vaatest määrad need klahvid teiste tegevuste käivitamiseks, siis sa asendad järgnevad eelseadistused.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Kiirklahv</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Tegevus</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Sulge rakenduse aken või välju täisekraanivaatest</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Paremale</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Järgmine pilt</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Tühikuklahv</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>Lõppu</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Viimane pilt</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Vasakul</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Eelmine pilt</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Tagasisammuklahv</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Algusesse</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Esimene pilt</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Käivita täisekraanivaates (näiteks omab mõtet paaniva aknahalduri puhul)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="102"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Tee ekraanitõmmis (pigem soovitame kasutada rakendust screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>DIR</source>
        <translation>DIR</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Tee ekraanitõmmis ja salvesta määratud kausta ilma kasutajaliidest kasutamata (tänaseks on see meetod vananenud ja pigem kasuta rakendust screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="117"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FAIL1, FAIL2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>päringuvastuse teadmata viga</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>päringuvastuse teadmata viga</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>päringuvastuse teadmata viga</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>About</source>
        <translation>Rakenduse teave</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>A simple and fast image viewer</source>
        <translation>Lihtne ja kiire rakendus piltide vaatamiseks</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Copyright (C) </source>
        <translation>Autoriõigused (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>2013-2021</source>
        <translation>2013-2021</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>LXQt Project</source>
        <translation>LXQt Projekt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Development: </source>
        <translation>Arendus: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Author: </source>
        <translation>Autor: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Open File</source>
        <translation>Ava fail</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Image files (%1)</source>
        <translation>Pildifailid (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Open directory</source>
        <translation>Ava kaust</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Save File</source>
        <translation>Salvesta fail</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Laadin...) - Pildinäitaja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Laadimine ei õnnestunud) - Pildinäitaja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="851"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Pildinäitaja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Pildinäitaja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1294"/>
        <source>Thumbnails</source>
        <translation>Pisipildid</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1389"/>
        <source>EXIF Data</source>
        <translation>EXIF-kirjed</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Kustuta</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Kiirklahvi eemaldamiseks vajuta
toimetamisvaates muuteklahvi.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="206"/>
        <source>Bottom</source>
        <translation>All</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="207"/>
        <source>Top</source>
        <translation>Üleval</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="208"/>
        <source>Left</source>
        <translation>Vasakul</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="334"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Hoiatus: Tegemist on korduva kiirklahviga!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="351"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Korduv kiirklahv jäi salvestamata.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Sellesse pildivormingusse ei saa salvestada!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Suurus:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Asukoht:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>Alusta</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>Lõpeta</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>Sulge</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Pildinäitaja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>&amp;Hiljuti avatud failid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>&amp;About</source>
        <translation>&amp;Rakenduse teave</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Annotations Toolbar</source>
        <translation>Joonistatavate märkmete tööriistariba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Ava &amp;rakendusega...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Sorting</source>
        <translation>Sortimine</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>&amp;Peidetud kiirklahvid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Open…</source>
        <translation>&amp;Ava…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Laadi uuesti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>&amp;Save</source>
        <translation>&amp;Salvesta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Save &amp;As</source>
        <translation>Salvesta &amp;kui</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;In</source>
        <translation>Suumi &amp;sisse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>Zoom &amp;Out</source>
        <translation>Suumi &amp;välja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Kopeeri lõikelauale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Next File</source>
        <translation>Järgmine fail</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Previous File</source>
        <translation>Eelmine fail</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Original Size</source>
        <translation>Algne suurus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Fit</source>
        <translation>&amp;Mahuta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Pööra &amp;päripäeva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Pööra &amp;vastupäeva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>P&amp;references</source>
        <translation>Ee&amp;listused</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>&amp;Print</source>
        <translation>&amp;Trüki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>First File</source>
        <translation>Esimene fail</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Home</source>
        <translation>Algusesse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="437"/>
        <source>Last File</source>
        <translation>Viimane fail</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>End</source>
        <translation>Lõppu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>&amp;New Window</source>
        <translation>&amp;Uus aken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Peegelda &amp;horisontaalselt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>Capture Screenshot</source>
        <translation>Tee ekraanitõmmis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Täisekraanivaade</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>Flip &amp;Vertically</source>
        <translation>Peegelda &amp;vertikaalselt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Aseta lõikelaualt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Slaidiseanss</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="518"/>
        <source>&amp;Delete</source>
        <translation>&amp;Kustuta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <source>Show Thumbnails</source>
        <translation>Näita pisipilte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>File Properties</source>
        <translation>Faili omadused</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Open &amp;Directory</source>
        <translation>Ava &amp;kaust</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Upload</source>
        <translation>Laadi veebi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="561"/>
        <source>Upload the image</source>
        <translation>Laadi pilt üles</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Show EXIF Data</source>
        <translation>Näita EXIF-kirjeid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>No Tool</source>
        <translation>Eemalda valitud tööriistad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Deselect all drawing tools</source>
        <translation>Eemalda kõik tööriistad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>Draw Arrow</source>
        <translation>Joonista nool</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="602"/>
        <source>Draw an arrow</source>
        <translation>Joonista üks nool</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="614"/>
        <source>Draw Rectangle</source>
        <translation>Joonista ristkülik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Draw a hollow rectangle</source>
        <translation>Joonista üks seest tühi ristkülik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="629"/>
        <source>Draw Circle</source>
        <translation>Joonista ring</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Draw a hollow circle</source>
        <translation>Joonista üks seest tühi ring</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="644"/>
        <source>Draw Number</source>
        <translation>Joonista number</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Draw incrementing numbers</source>
        <translation>Joonista kasvavaid numbreid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Menubar</source>
        <translation>Menüüriba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <source>&amp;Main Toolbar</source>
        <translation>&amp;Põhiline tööriistariba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Main Toolbar</source>
        <translation>Põhiline tööriistariba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Joonistatavate märkmete tööriistariba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="691"/>
        <location filename="../mainwindow.ui" line="694"/>
        <source>Show Outline</source>
        <translation>Näita äärejoont</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="705"/>
        <source>Copy Pa&amp;th</source>
        <translation>Kopeeri asukoh&amp;t</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy path</source>
        <translation>Kopeeri asukoht</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="716"/>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Rename</source>
        <translation>Muuda nime</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Resize</source>
        <translation>Muuda suurust</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="739"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Failinime alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <source>By File Name</source>
        <translation>Failinime alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>By &amp;Modification Time</source>
        <translation>&amp;Muutmise aja alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>By Modification Time</source>
        <translation>Muutmise aja alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>By C&amp;reation Time</source>
        <translation>&amp;Loomise aja alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>By Creation Time</source>
        <translation>Loomise aja alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="772"/>
        <source>By File &amp;Size</source>
        <translation>Faili &amp;suuruse alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>By File Size</source>
        <translation>Faili suuruse alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="783"/>
        <source>By File &amp;Type</source>
        <translation>Faili&amp;tüübi alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>By File Type</source>
        <translation>Failitüübi alusel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Fail</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>&amp;Abiteave</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Liigu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Vaata</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>&amp;Edit</source>
        <translation>&amp;Muuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Toolbar</source>
        <translation>Tööriistariba</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Eelistused</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Ikooniteema:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Pisipildistaja failisuuruse ülempiir:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Tavaline taustavärv:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Täisekraanivaate taustavärv:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Hiljutiste failide arv:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <source>Slide show interval (seconds):</source>
        <translation>Slaidiseansi välp (sekundites):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="193"/>
        <source>Show image outline by default</source>
        <translation>Vaikimis näita pildi äärejoont</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Vaikimisi näita joonistatavate märkmete tööriistariba</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>Fit images when navigating</source>
        <translation>Kuvamisel mahuta pildid</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Pisipiltide mõõdud:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Kasuta süsteemi prügikasti (ja ära küsi uuesti)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Aken</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Vaikimisi kuva pisipiltide paneeli</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Vaikimisi näita Exif-kirjeid</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Vaikimisi näita menüüriba</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Vaikimisi näita põhilist tööriistariba</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Pilt</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="207"/>
        <source>Smooth images on zooming</source>
        <translation>Suumimisel näita pilte sujuvalt</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>Shortcuts</source>
        <translation>Kiirklahvid</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="234"/>
        <source>Action</source>
        <translation>Tegevus</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="239"/>
        <source>Shortcut</source>
        <translation>Kiirklahv</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="247"/>
        <source>Default</source>
        <translation>Vaikimisi väärtused</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Üldseadistused</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="989"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Muuda pildi mõõte</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Laius</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Kõrgus</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Praegune suurus:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Uus suurus:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Säilita proportsioonid</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Ekraanitõmmis</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Tee ekraanitõmmis</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Soovin tõmmist</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Tervest ekraanist</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Ainult aktiivsest aknast</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Valitud alast</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Salvesta hiirekursor</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Viivitus:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Kaasa akna pealkiri ja raam</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Laadi üles</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Kopeeri</translation>
    </message>
</context>
</TS>
